AVec

Struct AVec 

pub struct AVec<T> { /* private fields */ }
Vector supporting multiple non-overlapping writers or multiple readers. Blocks during resizes only. !todo panics on concurrent reads+writes

Implementations

Source

impl<T> AVec<T>

pub fn new(initial_capacity: usize) -> AVec<T>

Creates a new instance with given inital capacity

pub fn push(&self, value: T) -> usize

Adds an element to the vector and returns the insert position.

pub fn map<'a>(&'a self, size: usize) -> AVecMapGuard<'a, T>

Maps a slice of the vector for write access. Faster than individual pushes for size > 2.

pub fn len(&self) -> usize

Returns the current length of the vector.

pub fn grow(&self, required_capacity: usize)

Grow vector by given number of elements.

pub fn clear(&self)

Clears the vector.

pub fn get<'a>(&'a self) -> AVecReadGuard<'a, T>

Maps the entire vector for read access.

pub fn capacity(&self) -> usize

Returns current capacity. The vector will reallocate once this is exceeded.